@@ -1,7 +1,7 @@
 package RoleWithAttributes;
-our $VERSION = '0.11_01';
+our $VERSION = '0.11_02';
 
-use Moose::Role -traits => 'MooseX::MethodAttributes::Role::Meta::Role';
+use Moose::Role -traits => 'MethodAttributes';
 use namespace::clean -except => 'meta';
 
 sub foo : AnAttr { 'foo' }
